summaryrefslogtreecommitdiff
path: root/w32/subproc/sub_proc.c
diff options
context:
space:
mode:
authorPaul Smith <psmith@gnu.org>1997-04-07 07:21:16 +0000
committerPaul Smith <psmith@gnu.org>1997-04-07 07:21:16 +0000
commit0ada207e2dca2b69a65ce186e625e7f6397edd34 (patch)
treedc117c22dc40a3d94b4ba2c5acc71ac8e53582a9 /w32/subproc/sub_proc.c
parent7bb7ba784904b414b1f5f604414d232871f77a69 (diff)
downloadgunmake-0ada207e2dca2b69a65ce186e625e7f6397edd34.tar.gz
Changes for make 3.75.1
Diffstat (limited to 'w32/subproc/sub_proc.c')
-rw-r--r--w32/subproc/sub_proc.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/w32/subproc/sub_proc.c b/w32/subproc/sub_proc.c
index 4f1ded9..55aafec 100644
--- a/w32/subproc/sub_proc.c
+++ b/w32/subproc/sub_proc.c
@@ -395,7 +395,7 @@ process_begin(
exec_handle = find_file(exec_path, &file_info);
/*
* If we couldn't open the file, just assume that Win32 will be able
* to find and execute it.
*/
if (exec_handle == (HANDLE)HFILE_ERROR) {
@@ -578,7 +578,7 @@ proc_stdout_thread(sub_process *pproc)
for (;;) {
if (ReadFile( (HANDLE)pproc->sv_stdout[0], &c, 1, &nread, NULL)
== FALSE) {
-/* map_win32_error_to_string(GetLastError());*/
+/* map_windows32_error_to_string(GetLastError());*/
_endthreadex(0);
}
if (nread == 0)
@@ -609,7 +609,7 @@ proc_stderr_thread(sub_process *pproc)
for (;;) {
if (ReadFile( (HANDLE)pproc->sv_stderr[0], &c, 1, &nread, NULL) == FALSE) {
- map_win32_error_to_string(GetLastError());
+ map_windows32_error_to_string(GetLastError());
_endthreadex(0);
}
if (nread == 0)
@@ -718,7 +718,7 @@ process_pipe_io(
one second to collect all remaining output */
if (wait_return == WAIT_FAILED) {
-/* map_win32_error_to_string(GetLastError());*/
+/* map_windows32_error_to_string(GetLastError());*/
pproc->last_err = GetLastError();
pproc->lerrno = E_SCALL;
goto done;
@@ -835,7 +835,7 @@ process_file_io(
wait_return = WaitForSingleObject(childhand, INFINITE);
if (wait_return != WAIT_OBJECT_0) {
-/* map_win32_error_to_string(GetLastError());*/
+/* map_windows32_error_to_string(GetLastError());*/
pproc->last_err = GetLastError();
pproc->lerrno = E_SCALL;
goto done2;
@@ -883,7 +883,7 @@ process_cleanup(
/*
* Try to protect against WIN32 argument munging. This function takes
* an argv vector and outputs a 'protected' string as a return
* value. The return code can be safely passed to CreateProcess().
*
@@ -395,7 +395,7 @@ process_begin(
exec_handle = find_file(exec_path, &file_info);
/*
- * If we couldn't open the file, just assume that Win32 will be able
+ * If we couldn't open the file, just assume that Windows32 will be able
* to find and execute it.
*/
@@ -883,7 +883,7 @@ process_cleanup(
/*
- * Try to protect against WIN32 argument munging. This function takes
+ * Try to protect against WINDOWS32 argument munging. This function takes
* an argv vector and outputs a 'protected' string as a return
* value. The return code can be safely passed to CreateProcess().